/*!
* \file controleur.c
* \brief Fichier contenant le code des fonctions du controleur.
*/

#include <stdio.h>
#include <stdlib.h>

#include "partie.h"
#include "joueur.h"
#include "affichageConsole2.h"
#include "joueurList.h"
#include "case.h"
#include "personnage.h"
#include "classe.h"

  /*!
 * \fn int choixPrincipal()
 * \brief La fonction fait l'interface entre le moteur et l'affichage du jeu pour le premier choix principal d'un Joueur lors de son tour.
 *
 * \param La Partie p en cours.
 * \return un entier representant la valeur du choix du Joueur.
 */
int choixPrincipal(Partie * p){
    int choix;
    choix = 0;
    affichePremierChoix(getNomJoueur(getCurrentJoueur(getListJoueur(p))),&choix);
    return choix;
}

  /*!
 * \fn int choixActionPersonnage(Partie * p)
 * \brief La fonction fait l'interface entre le moteur et l'affichage du jeu pour le choix d'une action d'un Personnage.
 *
 * \param La Partie p en cours.
 * \return un entier representant la valeur du choix du Joueur.
 */
int choixActionPersonnage(Partie * p, Personnage * persSel, Joueur * j){
    int i;
    i=0;
    afficheChoixActionPersonnage(getNomJoueur(j),getNomPersonnage(persSel),&i);
    return i;
}

  /*!
 * \fn Case * entrerCoordonnees(Partie * p)
 * \brief La fonction fait l'interface entre le moteur et l'affichage du jeu pour la saisie de coordonnees.
 *
 * \param La Partie p en cours.
 * \return Un pointeur vers la Case aux coordonnees entrees, NULL si les coordonnees ne sont pas valides.
 */
Case * entrerCoordonnees(Partie * p){
    int x, y;
    Case * caseTemp = NULL;
    x=-1;
    y=-1;
    afficherEntrerCoordonnees(&x,&y);
    caseTemp=trouverCase(getCarte(p),x,y);
    return caseTemp;
}

  /*!
 * \fn void personnageSelectionne(Partie * p)
 * \brief La fonction fait l'interface entre le moteur du jeu et l'affichage pour l'affichage des caracteristiques d'un Personnage.
 *
 * \param La Partie p en cours.
 */
void personnageSelectionne(Partie * p, Personnage * personnageSel){
    char * nP = getNomPersonnage(personnageSel);
    char * nC = getNomClasse(getClasse(personnageSel));
    char * nJ = getNomJoueur(appartientJoueur(personnageSel,p));
    int etat[6]={
                    get_PV(personnageSel),
                    getPVMax(getClasse(personnageSel)),
                    get_mana(personnageSel),
                    getManaMax(getClasse(personnageSel)),
                    get_PD(personnageSel),
                    getPDMax(getClasse(personnageSel))
                };
    afficheCaracteristiquesPersonnage(nJ,nP,nC,etat);
}
